
# Version 1.0.0

+ Add DfoTuneCfn class that can be used to tune hyperparameters of traditional CFN models
+ Remove decimal parameter for metrics in all classes
+ Add publish workflow
+ Add documentation website
+ Add zenodo DOI, CITATION.cff

----------------------------------------------------------------------------------------

# Version 0.1.0

+ Add `CfnRegressor` and `CfnClassifier` classes for Gradient Descent-based CFN models
+ Add `DfoCfnRegressor`, `DfoCfnClassifier` classes for Derivative Free-based CFN models
+ Update examples and tests folders
+ Add infor (CODE_OF_CONDUCT.md, MANIFEST.in, LICENSE, requirements.txt)
